@@ -136,7 +136,7 @@
 </node>
 </node>
 <node COLOR="#ffffff" CREATED="1342208091863" ID="ID_1615681583" MODIFIED="1349124451902" TEXT="post on youtube and vimeo"/>
-<node COLOR="#ffffff" CREATED="1344859408126" ID="ID_286503481" MODIFIED="1349124471669" TEXT="multiple short clips at 60-90 seconds">
+<node COLOR="#ffff00" CREATED="1344859408126" ID="ID_286503481" MODIFIED="1356232255095" TEXT="multiple short clips at 60-90 seconds">
 <node COLOR="#ffff00" CREATED="1344865413965" ID="ID_1413822213" MODIFIED="1347024434412" TEXT="01 - Introduction"/>
 <node COLOR="#ffff00" CREATED="1344865433963" ID="ID_800229671" MODIFIED="1347024434412" TEXT="02 - Starting up and loading"/>
 <node COLOR="#ffff00" CREATED="1344865538241" FOLDED="true" ID="ID_1916417406" MODIFIED="1349124602904" TEXT="03 - Mini">
@@ -263,111 +263,111 @@
 <node COLOR="#ffff00" CREATED="1346322057042" ID="ID_1557866751" MODIFIED="1349277952175" TEXT="15 - What slipery chicken does"/>
 <node COLOR="#ffff00" CREATED="1346335071595" ID="ID_21337141" MODIFIED="1349355858611" TEXT="16 - note selection algorithm"/>
 <node COLOR="#ffff00" CREATED="1346333614625" ID="ID_954390880" MODIFIED="1349448965907" TEXT="17 - output"/>
-<node COLOR="#ff9900" CREATED="1344867495186" ID="ID_25687912" MODIFIED="1348080883509" TEXT="18 - chop">
+<node COLOR="#ffff00" CREATED="1344867495186" FOLDED="true" ID="ID_25687912" MODIFIED="1354827746684" TEXT="18 - chop">
 <font BOLD="true" NAME="Dialog" SIZE="11"/>
-<node COLOR="#ff9900" CREATED="1344867519103" ID="ID_1360623534" MODIFIED="1345309773041" TEXT="what it does"/>
-<node COLOR="#ff9900" CREATED="1344867504731" ID="ID_1951628526" MODIFIED="1345309773040" TEXT="chopping unit"/>
-<node COLOR="#ff9900" CREATED="1344867510971" ID="ID_1721043729" MODIFIED="1345309773040" TEXT="chop points"/>
-<node COLOR="#ff9900" CREATED="1344867553811" ID="ID_457063955" MODIFIED="1345309773040" TEXT="how it does it"/>
-<node COLOR="#ff9900" CREATED="1344867569516" ID="ID_1472671788" MODIFIED="1345309773040" TEXT="three levels"/>
-<node COLOR="#ff9900" CREATED="1344867576529" ID="ID_111724186" MODIFIED="1345309773040" TEXT="rthm-seq-palette chop">
-<node COLOR="#ff9900" CREATED="1344867584257" ID="ID_1621518750" MODIFIED="1345309773040" TEXT="example"/>
-<node COLOR="#ff9900" CREATED="1344867592687" ID="ID_1977868389" MODIFIED="1345309773040" TEXT="accessing rthm-seqs in a chopped palette"/>
+<node COLOR="#ffff00" CREATED="1344867519103" ID="ID_1360623534" MODIFIED="1354827743388" TEXT="what it does"/>
+<node COLOR="#ffff00" CREATED="1344867504731" ID="ID_1951628526" MODIFIED="1354827743388" TEXT="chopping unit"/>
+<node COLOR="#ffff00" CREATED="1344867510971" ID="ID_1721043729" MODIFIED="1354827743388" TEXT="chop points"/>
+<node COLOR="#ffff00" CREATED="1344867553811" ID="ID_457063955" MODIFIED="1354827743388" TEXT="how it does it"/>
+<node COLOR="#ffff00" CREATED="1344867569516" ID="ID_1472671788" MODIFIED="1354827743387" TEXT="three levels"/>
+<node COLOR="#ffff00" CREATED="1344867576529" ID="ID_111724186" MODIFIED="1354827743387" TEXT="rthm-seq-palette chop">
+<node COLOR="#ffff00" CREATED="1344867584257" ID="ID_1621518750" MODIFIED="1354827743387" TEXT="example"/>
+<node COLOR="#ffff00" CREATED="1344867592687" ID="ID_1977868389" MODIFIED="1354827743387" TEXT="accessing rthm-seqs in a chopped palette"/>
 </node>
 </node>
-<node COLOR="#ff9900" CREATED="1344867640206" ID="ID_718656161" MODIFIED="1348080902641" TEXT="19 - Intraphrasal looping">
-<node COLOR="#ff9900" CREATED="1344867692716" ID="ID_1631233694" MODIFIED="1345313022797" TEXT="rsp-orig"/>
-<node COLOR="#ff9900" CREATED="1344867695963" ID="ID_1424201306" MODIFIED="1345313022797" TEXT="rsp-chopped"/>
-<node COLOR="#ff9900" CREATED="1344867902900" ID="ID_1959261925" MODIFIED="1345313022797" TEXT="assembling the rsm from the rsp-chopped fragments">
-<node COLOR="#ff9900" CREATED="1344867939875" ID="ID_1012945804" MODIFIED="1345313309471" TEXT="using fibonacci-transitions to collect rsp-chopped frags"/>
+<node COLOR="#ffff00" CREATED="1344867640206" FOLDED="true" ID="ID_718656161" MODIFIED="1355350623484" TEXT="19 - Intraphrasal looping">
+<node COLOR="#ffff00" CREATED="1344867692716" ID="ID_1631233694" MODIFIED="1355341296773" TEXT="rsp-orig"/>
+<node COLOR="#ffff00" CREATED="1344867695963" ID="ID_1424201306" MODIFIED="1355341296773" TEXT="rsp-chopped"/>
+<node COLOR="#ffff00" CREATED="1344867902900" ID="ID_1959261925" MODIFIED="1355341296773" TEXT="assembling the rsm from the rsp-chopped fragments">
+<node COLOR="#ffff00" CREATED="1344867939875" ID="ID_1012945804" MODIFIED="1355341296773" TEXT="using fibonacci-transitions to collect rsp-chopped frags"/>
 </node>
-<node COLOR="#ff9900" CREATED="1344867608189" ID="ID_1922853367" MODIFIED="1345313022797" TEXT="re-bar"/>
+<node COLOR="#ffff00" CREATED="1344867608189" ID="ID_1922853367" MODIFIED="1355341296772" TEXT="re-bar"/>
 </node>
-<node COLOR="#ff9900" CREATED="1344881072850" ID="ID_279362906" MODIFIED="1348080930272" TEXT="20 - l-systems">
-<node COLOR="#ff9900" CREATED="1344881096852" ID="ID_482867439" MODIFIED="1345485809508" TEXT="basics">
-<node COLOR="#ff9900" CREATED="1344881098270" ID="ID_920909608" MODIFIED="1345485809508" TEXT="symbols"/>
-<node COLOR="#ff9900" CREATED="1344881101523" ID="ID_1832160484" MODIFIED="1345485809507" TEXT="rules"/>
-<node COLOR="#ff9900" CREATED="1344881103148" ID="ID_924052914" MODIFIED="1345485809507" TEXT="axiom"/>
+<node COLOR="#ffff00" CREATED="1344881072850" FOLDED="true" ID="ID_279362906" MODIFIED="1355528969418" TEXT="20 - l-systems">
+<node COLOR="#ffff00" CREATED="1344881096852" ID="ID_482867439" MODIFIED="1355450713159" TEXT="basics">
+<node COLOR="#ffff00" CREATED="1344881098270" ID="ID_920909608" MODIFIED="1355450713160" TEXT="symbols"/>
+<node COLOR="#ffff00" CREATED="1344881101523" ID="ID_1832160484" MODIFIED="1355450713160" TEXT="rules"/>
+<node COLOR="#ffff00" CREATED="1344881103148" ID="ID_924052914" MODIFIED="1355450713159" TEXT="axiom"/>
 </node>
-<node COLOR="#ff9900" CREATED="1344881150195" ID="ID_1889110401" MODIFIED="1345485809507" TEXT="l-for-lookup object"/>
-<node COLOR="#ff9900" CREATED="1344881161982" ID="ID_1279318697" MODIFIED="1345485809507" TEXT="get-l-sequence"/>
-<node COLOR="#ff9900" CREATED="1344881167510" ID="ID_1409887871" MODIFIED="1345485809507" TEXT="do-simple-lookup"/>
-<node COLOR="#ff9900" CREATED="1344881173422" ID="ID_1341346969" MODIFIED="1345485809507" TEXT="do-lookup">
-<node COLOR="#ff9900" CREATED="1344881178061" ID="ID_1017601381" MODIFIED="1345485809507" TEXT="fib trans"/>
+<node COLOR="#ffff00" CREATED="1344881150195" ID="ID_1889110401" MODIFIED="1355450725483" TEXT="l-for-lookup object"/>
+<node COLOR="#ffff00" CREATED="1344881161982" ID="ID_1279318697" MODIFIED="1355450725483" TEXT="get-l-sequence"/>
+<node COLOR="#ffff00" CREATED="1344881167510" ID="ID_1409887871" MODIFIED="1355450725483" TEXT="do-simple-lookup"/>
+<node COLOR="#ffff00" CREATED="1344881173422" ID="ID_1341346969" MODIFIED="1355528966557" TEXT="do-lookup">
+<node COLOR="#ffff00" CREATED="1344881178061" ID="ID_1017601381" MODIFIED="1355528966557" TEXT="fib trans"/>
 </node>
-<node COLOR="#ff9900" CREATED="1344881190741" ID="ID_1248019153" MODIFIED="1345485809507" TEXT="simple example with mini"/>
+<node COLOR="#ffff00" CREATED="1344881190741" ID="ID_1248019153" MODIFIED="1355528966557" TEXT="simple example with mini"/>
 </node>
-<node COLOR="#ff9900" CREATED="1344880562624" ID="ID_1377455075" MODIFIED="1348080945036" TEXT="21 - post-gen editing">
-<node COLOR="#ff9900" CREATED="1344880590828" ID="ID_1891780132" MODIFIED="1345471082420" TEXT="events v notes"/>
-<node COLOR="#ff9900" CREATED="1344880608758" ID="ID_1206366223" MODIFIED="1345471082420" TEXT="basic usage">
-<node COLOR="#ff9900" CREATED="1344880622438" ID="ID_1964362620" MODIFIED="1345471082419" TEXT="sc object"/>
-<node COLOR="#ff9900" CREATED="1344880611096" ID="ID_543480719" MODIFIED="1345471082419" TEXT="bar-number"/>
-<node COLOR="#ff9900" CREATED="1344880616598" ID="ID_603208587" MODIFIED="1345471082419" TEXT="player"/>
-<node COLOR="#ff9900" CREATED="1344880630671" ID="ID_1597603137" MODIFIED="1345471082419" TEXT="event- or note-number"/>
-<node COLOR="#ff9900" CREATED="1344880638095" ID="ID_1404288572" MODIFIED="1345471082419" TEXT="new value"/>
+<node COLOR="#ffff33" CREATED="1344880562624" FOLDED="true" ID="ID_1377455075" MODIFIED="1355867820467" TEXT="21 - post-gen editing">
+<node COLOR="#ffff33" CREATED="1344880590828" ID="ID_1891780132" MODIFIED="1355867819023" TEXT="events v notes"/>
+<node COLOR="#ffff33" CREATED="1344880608758" ID="ID_1206366223" MODIFIED="1355867819023" TEXT="basic usage">
+<node COLOR="#ffff33" CREATED="1344880622438" ID="ID_1964362620" MODIFIED="1355867819022" TEXT="sc object"/>
+<node COLOR="#ffff33" CREATED="1344880611096" ID="ID_543480719" MODIFIED="1355867819022" TEXT="bar-number"/>
+<node COLOR="#ffff33" CREATED="1344880616598" ID="ID_603208587" MODIFIED="1355867819022" TEXT="player"/>
+<node COLOR="#ffff33" CREATED="1344880630671" ID="ID_1597603137" MODIFIED="1355867819022" TEXT="event- or note-number"/>
+<node COLOR="#ffff33" CREATED="1344880638095" ID="ID_1404288572" MODIFIED="1355867819022" TEXT="new value"/>
 </node>
-<node COLOR="#ff9900" CREATED="1344880647573" ID="ID_1557761225" MODIFIED="1345471708217" TEXT="examples">
-<node COLOR="#ff9900" CREATED="1344880668545" ID="ID_1914416113" MODIFIED="1345471210715" TEXT="change-pitch"/>
-<node COLOR="#ff9900" CREATED="1344880648996" ID="ID_1825859693" MODIFIED="1345471259411" TEXT="add-mark-to-note"/>
-<node COLOR="#ff9900" CREATED="1344880674441" ID="ID_1899491586" MODIFIED="1345471311278" TEXT="rm-marks-from-note"/>
-<node COLOR="#ff9900" CREATED="1344880696069" ID="ID_1438415590" MODIFIED="1345471479440" TEXT="tie"/>
-<node COLOR="#ff9900" CREATED="1344880703477" ID="ID_1612641872" MODIFIED="1345471708217" TEXT="double-events/move-events"/>
+<node COLOR="#ffff33" CREATED="1344880647573" ID="ID_1557761225" MODIFIED="1355867819021" TEXT="examples">
+<node COLOR="#ffff33" CREATED="1344880668545" ID="ID_1914416113" MODIFIED="1355867819021" TEXT="change-pitch"/>
+<node COLOR="#ffff33" CREATED="1344880648996" ID="ID_1825859693" MODIFIED="1355867819021" TEXT="add-mark-to-note"/>
+<node COLOR="#ffff33" CREATED="1344880674441" ID="ID_1899491586" MODIFIED="1355867819021" TEXT="rm-marks-from-note"/>
+<node COLOR="#ffff33" CREATED="1344880696069" ID="ID_1438415590" MODIFIED="1355867819020" TEXT="tie"/>
+<node COLOR="#ffff33" CREATED="1344880703477" ID="ID_1612641872" MODIFIED="1355867819020" TEXT="double-events/move-events"/>
 </node>
 </node>
-<node COLOR="#ff9900" CREATED="1344881207148" ID="ID_1901094604" MODIFIED="1348080970903" TEXT="23 - rthm-chains">
-<node COLOR="#ff9900" CREATED="1344881228463" ID="ID_1029160115" MODIFIED="1345487035518" TEXT="what it does">
-<node COLOR="#ff9900" CREATED="1344881245790" ID="ID_217485605" MODIFIED="1345487035517" TEXT="Algorithmic generation of 2-voice rthm-seq-palette and rthm-seq-map."/>
-<node COLOR="#ff9900" CREATED="1344881269344" ID="ID_1315727590" MODIFIED="1345487035517" TEXT="generated from ">
-<node COLOR="#ff9900" CREATED="1344881276480" ID="ID_49979105" MODIFIED="1345487035517" TEXT="shorter 1-beat frags"/>
-<node COLOR="#ff9900" CREATED="1344881281985" ID="ID_1875859686" MODIFIED="1345487035517" TEXT="longer 2- or 3-beat frags"/>
+<node COLOR="#ffff00" CREATED="1344881207148" FOLDED="true" ID="ID_1901094604" MODIFIED="1356060491736" TEXT="22 - rthm-chains">
+<node COLOR="#ffff00" CREATED="1344881228463" ID="ID_1029160115" MODIFIED="1356060486028" TEXT="what it does">
+<node COLOR="#ffff00" CREATED="1344881245790" ID="ID_217485605" MODIFIED="1356060486027" TEXT="Algorithmic generation of 2-voice rthm-seq-palette and rthm-seq-map."/>
+<node COLOR="#ffff00" CREATED="1344881269344" ID="ID_1315727590" MODIFIED="1356060486027" TEXT="generated from ">
+<node COLOR="#ffff00" CREATED="1344881276480" ID="ID_49979105" MODIFIED="1356060486027" TEXT="shorter 1-beat frags"/>
+<node COLOR="#ffff00" CREATED="1344881281985" ID="ID_1875859686" MODIFIED="1356060486027" TEXT="longer 2- or 3-beat frags"/>
 </node>
 </node>
-<node COLOR="#ff9900" CREATED="1344881219351" ID="ID_918601054" MODIFIED="1345487035517" TEXT="procession"/>
-<node COLOR="#ff9900" CREATED="1344881314145" ID="ID_1278590909" MODIFIED="1345487035517" TEXT="make-rthm-chain"/>
-<node COLOR="#ff9900" CREATED="1344881427874" ID="ID_1888114642" MODIFIED="1345487035517" TEXT="add voice"/>
-<node COLOR="#ff9900" CREATED="1344881375901" ID="ID_1286156947" MODIFIED="1345487035516" TEXT="some helpful post-gen methods">
-<node COLOR="#ff9900" CREATED="1344881346046" ID="ID_342150688" MODIFIED="1345487035516" TEXT="consolidate-notes"/>
-<node COLOR="#ff9900" CREATED="1344881352740" ID="ID_929240879" MODIFIED="1345487035516" TEXT="consolidate-rests-max"/>
-<node COLOR="#ff9900" CREATED="1344881394781" ID="ID_1305035386" MODIFIED="1345487035516" TEXT="map-over-bars"/>
-<node COLOR="#ff9900" CREATED="1344881368885" ID="ID_709846399" MODIFIED="1345487035516" TEXT="tie-over-rests"/>
-<node COLOR="#ff9900" CREATED="1344881389125" ID="ID_1622258614" MODIFIED="1345487035515" TEXT="handle-ties"/>
+<node COLOR="#ffff00" CREATED="1344881219351" ID="ID_918601054" MODIFIED="1356060486027" TEXT="procession"/>
+<node COLOR="#ffff00" CREATED="1344881314145" ID="ID_1278590909" MODIFIED="1356060486027" TEXT="make-rthm-chain"/>
+<node COLOR="#ffff00" CREATED="1344881427874" ID="ID_1888114642" MODIFIED="1356060486026" TEXT="add voice"/>
+<node COLOR="#ffff00" CREATED="1344881375901" ID="ID_1286156947" MODIFIED="1356060486026" TEXT="some helpful post-gen methods">
+<node COLOR="#ffff00" CREATED="1344881346046" ID="ID_342150688" MODIFIED="1356060486026" TEXT="consolidate-notes"/>
+<node COLOR="#ffff00" CREATED="1344881352740" ID="ID_929240879" MODIFIED="1356060486026" TEXT="consolidate-rests-max"/>
+<node COLOR="#ffff00" CREATED="1344881394781" ID="ID_1305035386" MODIFIED="1356060486026" TEXT="map-over-bars"/>
+<node COLOR="#ffff00" CREATED="1344881368885" ID="ID_709846399" MODIFIED="1356060486026" TEXT="tie-over-rests"/>
+<node COLOR="#ffff00" CREATED="1344881389125" ID="ID_1622258614" MODIFIED="1356060486025" TEXT="handle-ties"/>
 </node>
-<node CREATED="1349878828364" ID="ID_456077079" MODIFIED="1349878833641" TEXT="might not get beyond this one"/>
+<node COLOR="#ffff00" CREATED="1349878828364" ID="ID_456077079" MODIFIED="1356060486025" TEXT="might not get beyond this one"/>
 </node>
-<node COLOR="#ff9900" CREATED="1344880962828" ID="ID_931426660" MODIFIED="1348080957356" TEXT="22 - permutations">
-<node COLOR="#ff9900" CREATED="1344880996762" ID="ID_811368570" MODIFIED="1345484427751" TEXT="permutations"/>
-<node COLOR="#ff9900" CREATED="1344881005922" ID="ID_468401809" MODIFIED="1345484427750" TEXT="inefficient-permutations"/>
-<node COLOR="#ff9900" CREATED="1344881019089" ID="ID_952145950" MODIFIED="1345484427750" TEXT="inefficiently-permutate"/>
-<node COLOR="#ff9900" CREATED="1344881026608" ID="ID_197785136" MODIFIED="1345484427750" TEXT="shuffle"/>
-<node COLOR="#ff9900" CREATED="1344881037362" ID="ID_179941490" MODIFIED="1345484427750" TEXT="move-repeats"/>
-<node COLOR="#ff9900" CREATED="1344881043083" ID="ID_1713685744" MODIFIED="1345484427750" TEXT="example with a mini">
-<node COLOR="#ff9900" CREATED="1344881048436" ID="ID_253530537" MODIFIED="1345484427750" TEXT="use one of the examples from workshop"/>
+<node COLOR="#ffff00" CREATED="1344880962828" FOLDED="true" ID="ID_931426660" MODIFIED="1356206464317" TEXT="23 - permutations">
+<node COLOR="#ffff00" CREATED="1344880996762" ID="ID_811368570" MODIFIED="1356206460233" TEXT="permutations"/>
+<node COLOR="#ffff00" CREATED="1344881005922" ID="ID_468401809" MODIFIED="1356206460233" TEXT="inefficient-permutations"/>
+<node COLOR="#ffff00" CREATED="1344881019089" ID="ID_952145950" MODIFIED="1356206460233" TEXT="inefficiently-permutate"/>
+<node COLOR="#ffff00" CREATED="1344881026608" ID="ID_197785136" MODIFIED="1356206460233" TEXT="shuffle"/>
+<node COLOR="#ffff00" CREATED="1344881037362" ID="ID_179941490" MODIFIED="1356206460232" TEXT="move-repeats"/>
+<node COLOR="#ffff00" CREATED="1344881043083" ID="ID_1713685744" MODIFIED="1356206460232" TEXT="example with a mini">
+<node COLOR="#ffff00" CREATED="1344881048436" ID="ID_253530537" MODIFIED="1356206460232" TEXT="use one of the examples from workshop"/>
 </node>
 </node>
-<node COLOR="#ff9900" CREATED="1344880732931" ID="ID_988596013" MODIFIED="1348080986393" TEXT="24 - score layout 1">
-<node COLOR="#ff9900" CREATED="1344880766391" ID="ID_550971803" MODIFIED="1345478320635" TEXT="header">
-<node COLOR="#ff9900" CREATED="1345477826902" ID="ID_1774715039" MODIFIED="1345478320635" TEXT="title"/>
-<node COLOR="#ff9900" CREATED="1345477829685" ID="ID_1514979558" MODIFIED="1345478320635" TEXT="composer"/>
+<node COLOR="#ffff00" CREATED="1344880732931" FOLDED="true" ID="ID_988596013" MODIFIED="1356224130951" TEXT="24 - score layout 1">
+<node COLOR="#ffff00" CREATED="1344880766391" ID="ID_550971803" MODIFIED="1356224127667" TEXT="header">
+<node COLOR="#ffff00" CREATED="1345477826902" ID="ID_1774715039" MODIFIED="1356224127667" TEXT="title"/>
+<node COLOR="#ffff00" CREATED="1345477829685" ID="ID_1514979558" MODIFIED="1356224127667" TEXT="composer"/>
 </node>
-<node COLOR="#ff9900" CREATED="1344880768927" ID="ID_1744034437" MODIFIED="1345478320635" TEXT="score order"/>
-<node COLOR="#ff9900" CREATED="1344880788359" ID="ID_1789379341" MODIFIED="1345478320635" TEXT="staff grouping"/>
-<node COLOR="#ff9900" CREATED="1344880840019" ID="ID_1192693260" MODIFIED="1345478320635" TEXT="rehearsal letters"/>
+<node COLOR="#ffff00" CREATED="1344880768927" ID="ID_1744034437" MODIFIED="1356224127667" TEXT="score order"/>
+<node COLOR="#ffff00" CREATED="1344880788359" ID="ID_1789379341" MODIFIED="1356224127667" TEXT="staff grouping"/>
+<node COLOR="#ffff00" CREATED="1344880840019" ID="ID_1192693260" MODIFIED="1356224127666" TEXT="rehearsal letters"/>
 </node>
-<node COLOR="#ff9900" CREATED="1344880825046" ID="ID_1722438408" MODIFIED="1348081000652" TEXT="25 - score layout 2">
-<node COLOR="#ff9900" CREATED="1344880828702" ID="ID_1019365035" MODIFIED="1345480731558" TEXT="bar line types"/>
-<node COLOR="#ff9900" CREATED="1344880861097" ID="ID_14130481" MODIFIED="1345480731559" TEXT="clefs">
-<node COLOR="#ff9900" CREATED="1344880875695" ID="ID_941489717" MODIFIED="1345480731559" TEXT="disable auto-clefs first"/>
-<node COLOR="#ff9900" CREATED="1344880893557" ID="ID_381925327" MODIFIED="1345480731559" TEXT="add-clef/delete-clefs"/>
+<node COLOR="#ffff00" CREATED="1344880825046" FOLDED="true" ID="ID_1722438408" MODIFIED="1356232260977" TEXT="25 - score layout 2">
+<node COLOR="#ffff00" CREATED="1344880828702" ID="ID_1019365035" MODIFIED="1356232248005" TEXT="bar line types"/>
+<node COLOR="#ffff00" CREATED="1344880861097" ID="ID_14130481" MODIFIED="1356232248005" TEXT="clefs">
+<node COLOR="#ffff00" CREATED="1344880875695" ID="ID_941489717" MODIFIED="1356232248005" TEXT="disable auto-clefs first"/>
+<node COLOR="#ffff00" CREATED="1344880893557" ID="ID_381925327" MODIFIED="1356232248004" TEXT="add-clef/delete-clefs"/>
 </node>
-<node COLOR="#ff9900" CREATED="1344880919535" ID="ID_1111039459" MODIFIED="1345481435000" TEXT="scores in c"/>
-<node COLOR="#ff9900" CREATED="1344880935395" ID="ID_679681324" MODIFIED="1345481711579" TEXT="parts"/>
+<node COLOR="#ffff00" CREATED="1344880919535" ID="ID_1111039459" MODIFIED="1356232248004" TEXT="scores in c"/>
+<node COLOR="#ffff00" CREATED="1344880935395" ID="ID_679681324" MODIFIED="1356232248004" TEXT="parts"/>
 </node>
 </node>
 </node>
 </node>
 <node COLOR="#ffffff" CREATED="1342208225768" ID="ID_535070653" MODIFIED="1349124543355" POSITION="left" TEXT="september">
-<node COLOR="#ffffff" CREATED="1341491446242" ID="ID_274702155" MODIFIED="1349124504740" TEXT="compositions">
-<node COLOR="#ff0000" CREATED="1342207721530" ID="ID_1069394501" MODIFIED="1342207739241" TEXT="A rthm-chains piece"/>
+<node COLOR="#ffff00" CREATED="1341491446242" ID="ID_274702155" MODIFIED="1356232269890" TEXT="compositions">
+<node COLOR="#ffff00" CREATED="1342207721530" ID="ID_1069394501" MODIFIED="1356232258946" TEXT="A rthm-chains piece"/>
 </node>
 <node COLOR="#ffffff" CREATED="1338981748877" ID="ID_1519032688" MODIFIED="1349124548830" TEXT="manual">
 <node COLOR="#ffffff" CREATED="1341491502269" ID="ID_1166044590" MODIFIED="1351274278371" TEXT="pages">
